@@ -6,8 +6,8 @@ Pyramid authn policy that ties together multiple backends.
 """
 
 __ver_major__ = 0
-__ver_minor__ = 3
-__ver_patch__ = 2
+__ver_minor__ = 4
+__ver_patch__ = 0
 __ver_sub__ = ""
 __ver_tuple__ = (__ver_major__, __ver_minor__, __ver_patch__, __ver_sub__)
 __version__ = "%d.%d.%d%s" % __ver_tuple__
@@ -84,6 +84,8 @@ class MultiAuthenticationPolicy(object):
                     break
                 if self._callback(userid, request) is not None:
                     break
+                else:
+                    userid = None
         return userid
 
     def unauthenticated_userid(self, request):
